@@ -2,7 +2,7 @@
 # -*- coding: latin-1 -*-
 
 """
-Spaceship prototype (July 6, 2013)
+Spaceship prototype (November 8, 2013)
 
 My solution (slightly retouched) of the mini-project #7 of the course
 https://www.coursera.org/course/interactivepython (Coursera 2013).
@@ -24,11 +24,11 @@ import math
 import random
 
 try:
-    from user17_4TDF1HgJxDffzME import Loader
+    from user23_XEsEdVoFmntP29T import Loader
 
     import simplegui
 except:
-    from SimpleGUICS2Pygame.simplegui_lib import Loader
+    from SimpleGUICS2Pygame.simplegui_lib_loader import Loader
 
     import SimpleGUICS2Pygame.simpleguics2pygame as simplegui
 
@@ -469,9 +469,10 @@ def keyup(key):
 
 def quit():
     """
-    Stop timer and quit.
+    Stop timer and sounds, and quit.
     """
     timer.stop()
+    loader.pause_sounds()
     frame.stop()
 
 
